---
title: <span class="badge object-type-enum"></span> ValueTypes
---
# <span class="badge object-type-enum"></span> ValueTypes

## Definition

```python
class ValueTypes(enum.StrEnum):
    VALUE_TYPE_UNSPECIFIED = "VALUE_TYPE_UNSPECIFIED"
    BOOL = "BOOL"
    INT64 = "INT64"
    DOUBLE = "DOUBLE"
    STRING = "STRING"
    DISTRIBUTION = "DISTRIBUTION"
    MONEY = "MONEY"
```
